==> jc-1.4.0.tar.gz: soot/coffi/CONSTANT__5fFloat__5finfo.h <==
// class soot.coffi.CONSTANT_Float_info

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5d4d4f0389dc1a6c soot_coffi_CONSTANT__5fFloat__5finfo
// @dep_class e90f9ccbd070bf8a soot_coffi_cp__5finfo

// header file dependencies
// @dep_header soot_coffi_cp__5finfo

#include "soot/coffi/cp__5finfo.h"

#ifndef _JC_soot_coffi_CONSTANT__5fFloat__5finfo_H_
#define _JC_soot_coffi_CONSTANT__5fFloat__5finfo_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_coffi_cp__5finfo$object;

// Typedefs
typedef struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$sub_refs	_jc_soot_coffi_CONSTANT__5fFloat__5finfo$sub_refs;
typedef struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$sub_nonrefs	_jc_soot_coffi_CONSTANT__5fFloat__5finfo$sub_nonrefs;
typedef struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$refs	_jc_soot_coffi_CONSTANT__5fFloat__5finfo$refs;
typedef struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$nonrefs	_jc_soot_coffi_CONSTANT__5fFloat__5finfo$nonrefs;
typedef struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$object	_jc_soot_coffi_CONSTANT__5fFloat__5finfo$object;

typedef const struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$vmethods	_jc_soot_coffi_CONSTANT__5fFloat__5finfo$vmethods;
typedef const struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$vtable	_jc_soot_coffi_CONSTANT__5fFloat__5finfo$vtable;
typedef const struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$vtype	_jc_soot_coffi_CONSTANT__5fFloat__5finfo$vtype;

// Constructors
extern void _jc_soot_coffi_CONSTANT__5fFloat__5finfo$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$object *);

// Virtual methods
extern jint _jc_soot_coffi_CONSTANT__5fFloat__5finfo$method$compareTo$79b5fc6544b5d8ee(_jc_env *, struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$object *, struct _jc_object_array *, struct _jc_soot_coffi_cp__5finfo$object *, struct _jc_object_array *);
extern jfloat _jc_soot_coffi_CONSTANT__5fFloat__5finfo$method$convert$f59e7699e8086f9a(_jc_env *, struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$object *);
extern jint _jc_soot_coffi_CONSTANT__5fFloat__5finfo$method$size$345df5220fc60ade(_jc_env *, struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$object *);
extern struct _jc_java_lang_String$object *_jc_soot_coffi_CONSTANT__5fFloat__5finfo$method$toString$9f9bf0b6fdab502b(_jc_env *, struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$object *, struct _jc_object_array *);
extern struct _jc_java_lang_String$object *_jc_soot_coffi_CONSTANT__5fFloat__5finfo$method$typeName$93c74ee20480929f(_jc_env *, struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_CONSTANT__5fFloat__5finfo$method_info$compareTo$79b5fc6544b5d8ee;
extern _jc_method _jc_soot_coffi_CONSTANT__5fFloat__5finfo$method_info$convert$f59e7699e8086f9a;
extern _jc_method _jc_soot_coffi_CONSTANT__5fFloat__5finfo$method_info$size$345df5220fc60ade;
extern _jc_method _jc_soot_coffi_CONSTANT__5fFloat__5finfo$method_info$toString$9f9bf0b6fdab502b;
extern _jc_method _jc_soot_coffi_CONSTANT__5fFloat__5finfo$method_info$typeName$93c74ee20480929f;

// Virtual methods structure
struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$vmethods {
	jint	(*compareTo$79b5fc6544b5d8ee)(_jc_env *, struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$object *, struct _jc_object_array *, struct _jc_soot_coffi_cp__5finfo$object *, struct _jc_object_array *);
	jfloat	(*convert$f59e7699e8086f9a)(_jc_env *, struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$object *);
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$object *);
	struct _jc_java_lang_String$object	*(*toString$9f9bf0b6fdab502b)(_jc_env *, struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$object *, struct _jc_object_array *);
	struct _jc_java_lang_String$object	*(*typeName$93c74ee20480929f)(_jc_env *, struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$object *);
};

// Vtable
struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_cp__5finfo$vmethods	soot_coffi_cp__5finfo;
	_jc_soot_coffi_CONSTANT__5fFloat__5finfo$vmethods	soot_coffi_CONSTANT__5fFloat__5finfo;
};

// Vtype
struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$vtype {
	_jc_type			type;
	_jc_soot_coffi_CONSTANT__5fFloat__5finfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$refs {
    _jc_soot_coffi_CONSTANT__5fFloat__5finfo$sub_refs	soot_coffi_CONSTANT__5fFloat__5finfo;
    _jc_soot_coffi_cp__5finfo$sub_refs	soot_coffi_cp__5finfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$sub_nonrefs {
	jlong	bytes;
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_cp__5finfo$sub_nonrefs	soot_coffi_cp__5finfo;
    _jc_soot_coffi_CONSTANT__5fFloat__5finfo$sub_nonrefs	soot_coffi_CONSTANT__5fFloat__5finfo;
};

// Object instance structure
struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$object {
	_jc_soot_coffi_CONSTANT__5fFloat__5finfo$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_CONSTANT__5fFloat__5finfo$vtype	*vtype;
	_jc_soot_coffi_CONSTANT__5fFloat__5finfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_CONSTANT__5fFloat__5finfo$vtype _jc_soot_coffi_CONSTANT__5fFloat__5finfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_CONSTANT__5fFloat__5finfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_CONSTANT__5fFloat__5finfo$class_object;

#endif	/* _JC_soot_coffi_CONSTANT__5fFloat__5finfo_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/CONSTANT__5fFloat__5finfo.h <==
// class soot.coffi.CONSTANT_Float_info

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5d4d4f0389dc1a6c soot_coffi_CONSTANT__5fFloat__5finfo
// @dep_class e90f9ccbd070bf8a soot_coffi_cp__5finfo

// header file dependencies
// @dep_header soot_coffi_cp__5finfo

#include "soot/coffi/cp__5finfo.h"

#ifndef _JC_soot_coffi_CONSTANT__5fFloat__5finfo_H_
#define _JC_soot_coffi_CONSTANT__5fFloat__5finfo_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_coffi_cp__5finfo$object;

// Typedefs
typedef struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$sub_refs	_jc_soot_coffi_CONSTANT__5fFloat__5finfo$sub_refs;
typedef struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$sub_nonrefs	_jc_soot_coffi_CONSTANT__5fFloat__5finfo$sub_nonrefs;
typedef struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$refs	_jc_soot_coffi_CONSTANT__5fFloat__5finfo$refs;
typedef struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$nonrefs	_jc_soot_coffi_CONSTANT__5fFloat__5finfo$nonrefs;
typedef struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$object	_jc_soot_coffi_CONSTANT__5fFloat__5finfo$object;

typedef const struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$vmethods	_jc_soot_coffi_CONSTANT__5fFloat__5finfo$vmethods;
typedef const struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$vtable	_jc_soot_coffi_CONSTANT__5fFloat__5finfo$vtable;
typedef const struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$vtype	_jc_soot_coffi_CONSTANT__5fFloat__5finfo$vtype;

// Constructors
extern void _jc_soot_coffi_CONSTANT__5fFloat__5finfo$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_soot_coffi_CONSTANT__5fFloat__5finfo$method$compareTo$79b5fc6544b5d8ee(_jc_env *, struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$object *, struct _jc_object_array *, struct _jc_soot_coffi_cp__5finfo$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern jfloat _jc_soot_coffi_CONSTANT__5fFloat__5finfo$method$convert$f59e7699e8086f9a(_jc_env *, struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_coffi_CONSTANT__5fFloat__5finfo$method$size$345df5220fc60ade(_jc_env *, struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_coffi_CONSTANT__5fFloat__5finfo$method$toString$9f9bf0b6fdab502b(_jc_env *, struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_coffi_CONSTANT__5fFloat__5finfo$method$typeName$93c74ee20480929f(_jc_env *, struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_CONSTANT__5fFloat__5finfo$method_info$compareTo$79b5fc6544b5d8ee;
extern _jc_method _jc_soot_coffi_CONSTANT__5fFloat__5finfo$method_info$convert$f59e7699e8086f9a;
extern _jc_method _jc_soot_coffi_CONSTANT__5fFloat__5finfo$method_info$size$345df5220fc60ade;
extern _jc_method _jc_soot_coffi_CONSTANT__5fFloat__5finfo$method_info$toString$9f9bf0b6fdab502b;
extern _jc_method _jc_soot_coffi_CONSTANT__5fFloat__5finfo$method_info$typeName$93c74ee20480929f;

// Virtual methods structure
struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$vmethods {
	jint	(*compareTo$79b5fc6544b5d8ee)(_jc_env *, struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$object *, struct _jc_object_array *, struct _jc_soot_coffi_cp__5finfo$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
	jfloat	(*convert$f59e7699e8086f9a)(_jc_env *, struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$object *) _JC_JCNI_ATTR;
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$9f9bf0b6fdab502b)(_jc_env *, struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*typeName$93c74ee20480929f)(_jc_env *, struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_cp__5finfo$vmethods	soot_coffi_cp__5finfo;
	_jc_soot_coffi_CONSTANT__5fFloat__5finfo$vmethods	soot_coffi_CONSTANT__5fFloat__5finfo;
};

// Vtype
struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$vtype {
	_jc_type			type;
	_jc_soot_coffi_CONSTANT__5fFloat__5finfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$refs {
    _jc_soot_coffi_CONSTANT__5fFloat__5finfo$sub_refs	soot_coffi_CONSTANT__5fFloat__5finfo;
    _jc_soot_coffi_cp__5finfo$sub_refs	soot_coffi_cp__5finfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$sub_nonrefs {
	jlong	bytes;
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_cp__5finfo$sub_nonrefs	soot_coffi_cp__5finfo;
    _jc_soot_coffi_CONSTANT__5fFloat__5finfo$sub_nonrefs	soot_coffi_CONSTANT__5fFloat__5finfo;
};

// Object instance structure
struct _jc_soot_coffi_CONSTANT__5fFloat__5finfo$object {
	_jc_soot_coffi_CONSTANT__5fFloat__5finfo$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_CONSTANT__5fFloat__5finfo$vtype	*vtype;
	_jc_soot_coffi_CONSTANT__5fFloat__5finfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_CONSTANT__5fFloat__5finfo$vtype _jc_soot_coffi_CONSTANT__5fFloat__5finfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_CONSTANT__5fFloat__5finfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_CONSTANT__5fFloat__5finfo$class_object;

#endif	/* _JC_soot_coffi_CONSTANT__5fFloat__5finfo_H_ */
